"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const domnode_1 = require("./domnode");
const selector_1 = require("./selector");
class DOMTree {
    constructor(location) {
        this.root = domnode_1.DOMNode.rootNode(location);
        this.active = this.root;
        this.doctype = null;
    }
    pushActive(node) {
        this.active = node;
    }
    popActive() {
        if (this.active.isRootElement()) {
            return;
        }
        this.active = this.active.parent;
    }
    getActive() {
        return this.active;
    }
    resolveMeta(table) {
        this.visitDepthFirst((node) => table.resolve(node));
    }
    getElementsByTagName(tagName) {
        return this.root.getElementsByTagName(tagName);
    }
    visitDepthFirst(callback) {
        this.root.visitDepthFirst(callback);
    }
    find(callback) {
        return this.root.find(callback);
    }
    querySelector(selector) {
        const it = this.querySelectorImpl(selector);
        return it.next().value || null;
    }
    querySelectorAll(selector) {
        const it = this.querySelectorImpl(selector);
        return Array.from(it);
    }
    *querySelectorImpl(selector) {
        const pattern = new selector_1.Selector(selector);
        yield* pattern.match(this.root);
    }
}
exports.DOMTree = DOMTree;
