"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
class Reporter {
    constructor() {
        this.result = {};
    }
    static merge(reports) {
        const valid = reports.every(report => report.valid);
        const merged = {};
        reports.forEach((report) => {
            report.results.forEach((result) => {
                const key = result.filePath;
                if (merged.hasOwnProperty(key)) {
                    merged[key].messages = [].concat(merged[key].messages, result.messages);
                }
                else {
                    merged[key] = Object.assign({}, result);
                }
            });
        });
        return { valid, results: Object.keys(merged).map(key => merged[key]) };
    }
    add(node, rule, message, severity, location) {
        if (!this.result.hasOwnProperty(location.filename)) {
            this.result[location.filename] = [];
        }
        this.result[location.filename].push({
            ruleId: rule.name,
            severity,
            message,
            line: location.line,
            column: location.column,
        });
    }
    addManual(filename, message) {
        if (!this.result.hasOwnProperty(filename)) {
            this.result[filename] = [];
        }
        this.result[filename].push(message);
    }
    save() {
        return {
            valid: this.isValid(),
            results: Object.keys(this.result).map(filePath => {
                const messages = [].concat(this.result[filePath]).sort(messageSort);
                return {
                    filePath,
                    messages,
                    errorCount: countErrors(messages),
                    warningCount: countWarnings(messages),
                };
            }),
        };
    }
    isValid() {
        const numErrors = Object.values(this.result).reduce((sum, messages) => {
            return sum + countErrors(messages);
        }, 0);
        return numErrors === 0;
    }
}
exports.Reporter = Reporter;
function countErrors(messages) {
    return messages.filter(m => m.severity === config_1.Config.SEVERITY_ERROR).length;
}
function countWarnings(messages) {
    return messages.filter(m => m.severity === config_1.Config.SEVERITY_WARN).length;
}
function messageSort(a, b) {
    if (a.line < b.line) {
        return -1;
    }
    if (a.line > b.line) {
        return 1;
    }
    if (a.column < b.column) {
        return -1;
    }
    if (a.column > b.column) {
        return 1;
    }
    return 0;
}
exports.default = Reporter;
